@@ -14,9 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+
 require 'spec_helper'
 
-describe 'async_search.delete' do
+describe 'client#async_search.status' do
   let(:expected_args) do
     [
       'GET',
@@ -24,7 +25,7 @@ describe 'async_search.delete' do
       {},
       nil,
       {},
-      { endpoint: 'async_search.status' }
+      { defined_params: { id: 'foo' }, endpoint: 'async_search.status' }
     ]
   end
 
